@@ -15,7 +15,7 @@ has missing_after => 86400;
 has remove_after  => 864000;
 has tasks         => sub { {} };
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -250,7 +250,7 @@ These options are currently available:
 
   delay => 10
 
-Delay job for this many seconds from now.
+Delay job for this many seconds (from now).
 
 =item priority
 
@@ -355,6 +355,8 @@ Andrey Khozov
 
 Brian Medley
 
+Paul Williams
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
